#
# spec file for package geekodoc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without  tests

#
Name:           geekodoc
Version:        1.0.2.1
Release:        lp152.5.2
Summary:        DocBook based RNG Schema for SUSE Documentation
License:        GPL-3.0
Group:          Productivity/Publishing/DocBook
Url:            https://github.com/openSUSE/geekodoc/archive/%{name}-%{version}.tar.gz
Source:         %{name}-%{version}.tar.gz
BuildRequires:  docbook_5 >= 5.1
BuildRequires:  jing
BuildRequires:  libxml2-tools
BuildRequires:  make
BuildRequires:  python3-rnginline
BuildRequires:  python3-setuptools
BuildRequires:  trang
Requires:       sgml-skel >= 0.7
Requires(post): sgml-skel >= 0.7
Requires(postun): sgml-skel >= 0.7
Conflicts:      suse-xsl-stylesheets < 2.0.6
BuildArch:      noarch

%description
GeekoDoc is a RELAX NG schema used for current SUSE documentation.

%package -n novdoc
Version:        1.0_%{version}
Release:        lp152.5.2
Summary:        DocBook based Schema for older SUSE Documentation
Group:          Productivity/Publishing/DocBook
Conflicts:      suse-xsl-stylesheets < 2.0.6

%description -n novdoc
NovDoc is a DTD/RELAX NG schema used for older SUSE documentation.

%prep
%setup -q

%build
touch geekodoc/rng/geekodoc5.rnc
# GeekoDoc
make %{?_smp_mflags} VERBOSE=1 -C geekodoc/rng
make %{?_smp_mflags} VERBOSE=1 -C geekodoc/rng geekodoc5-flat.rng

# Novdoc
make %{?_smp_mflags} VERBOSE=1 -C novdoc/rng

%install
install -d %{buildroot}%{_datadir}/xml/{geekodoc/rng,novdoc/rng} \
           %{buildroot}%{_sysconfdir}/xml/catalog.d

# Install GeekoDoc:
cp geekodoc/rng/geekodoc5-flat.rn? %{buildroot}%{_datadir}/xml/geekodoc/rng

# Install Novdoc:
cp -a novdoc/dtd %{buildroot}%{_datadir}/xml/novdoc
cp novdoc/rng/novdocxi-flat.rn? novdoc/rng/novell.ent %{buildroot}%{_datadir}/xml/novdoc/rng

# Install catalogs:
cp catalog.d/* %{buildroot}%{_sysconfdir}/xml/catalog.d/

# Fixup catalog paths
sed -i 's#"\.\./#"%{_datadir}/xml/#' %{buildroot}%{_sysconfdir}/xml/catalog.d/*

%post
update-xml-catalog

%postun
update-xml-catalog

%post -n novdoc
update-xml-catalog

if [ ! -f %{_sysconfdir}/xml/suse-catalog.xml -a -x %{_bindir}/edit-xml-catalog ] ; then
    # susexsl entry
    edit-xml-catalog --group --catalog %{_sysconfdir}/xml/suse-catalog.xml \
       --del suse_schemas
    edit-xml-catalog --group --catalog %{_sysconfdir}/xml/suse-catalog.xml \
       --del novdoc-1.0
fi
exit 0

%postun -n novdoc
update-xml-catalog

%if 0%{with tests}
%check
cd geekodoc/tests
./run-tests.sh -V xmllint
./run-tests.sh -V jing
%endif

%files
%license LICENSE ChangeLog
%config %{_sysconfdir}/xml/catalog.d/geekodoc.xml
%{_datadir}/xml/geekodoc
%{_datadir}/xml/geekodoc/*

%files -n novdoc
%license LICENSE
%config %{_sysconfdir}/xml/catalog.d/novdoc.xml
%{_datadir}/xml/novdoc
%{_datadir}/xml/novdoc/*

%changelog
* Fri Feb  9 2018 thomas.schraitle@suse.com
- Bugfix release 1.0.2.1
  https://github.com/openSUSE/geekodoc/releases/tag/v1.0.2.1
  * Correct version in GeekoDoc schema
  * Add missing 'fig' value (#43)
  * Improve test suite
* Wed Feb  7 2018 thomas.schraitle@suse.com
- Add bcond_with tests to activate test suite
* Tue Feb  6 2018 thomas.schraitle@suse.com
- Release 1.0.2
  https://github.com/openSUSE/geekodoc/releases/tag/v1.0.2
  Only a package release without any changes in the schemas.
  Fixes issue #41 to reduce number of files in packages
* Tue Feb  6 2018 thomas.schraitle@suse.com
- Remove number of files in package; fixes openSUSE/geekodoc#41
  some files are only useful for development
* Tue Jan 30 2018 thomas.schraitle@suse.com
  Release 1.0.1
  https://github.com/openSUSE/geekodoc/releases/tag/v1.0.1
  * Geekodoc
  * Forbid xml:id on row and entry (#37)
  * Allow affiliation inside author (#36)
  * Forbid xml:id on remark (#32)
  * Inconsistency between informalfigure and informaltable (#35)
  * Allow sections (#34)
  * Novdoc
  no changes
* Thu Oct 26 2017 thomas.schraitle@suse.com
  Release 1.0.0
  https://github.com/openSUSE/geekodoc/releases/tag/v1.0.0
  * Geekodoc
  * Missing mediaobject in cover (#30)
  * Novdoc
  no changes
* Fri Oct 13 2017 thomas.schraitle@suse.com
  Release 0.9.9
  https://github.com/openSUSE/geekodoc/releases/tag/v0.9.9
  * Geekodoc
  * Allow lowercase Values in format attribute (#29)
  * Add list elements in taskprerequisites (#25)
  * Novdoc
  * No changes
* Fri Sep 15 2017 thomas.schraitle@suse.com
  Release 0.9.8
  https://github.com/openSUSE/geekodoc/releases/tag/v0.9.8
  Release 0.9.8
  * GeekoDoc
  * Restrict Possible Values in format Attribute (#24)
  * Fix outdated Schematron rules (#22)
  * Implement task elements (#20)
  * Adapt content model of task* elements (#1)
  * Add test cases and use Travis to check schema
  * Spec file:
  * Correct summary
* Thu Jun  1 2017 sknorr@suse.com
- Make sure that we ship the LICENSE file in the package
* Thu Dec  1 2016 toms@opensuse.org
  Release 0.9.7
  https://github.com/openSUSE/geekodoc/releases/tag/v0.9.7
  Release 0.9.7
  * GeekoDoc
  * link without "xlink:href" attribute is currently valid (#15)
  * Novdoc
  * Content model of step is not determinist (#17)
* Thu Nov 24 2016 toms@opensuse.org
  Release 0.9.6
  https://github.com/openSUSE/geekodoc/releases/tag/v0.9.6
  * GeekoDoc
  * Remove title in step (#4)
  * Empty <xref/> does not trigger a warning (#9)
  * Allow common attributes in link (#10)
  * Disallow xreflabel (#11)
  * Restrict <results> element (#14)
  * Novdoc
  * Missing novdocx-core.rnc (#5)
  * Allow <mediaobject> only in <figure> and
  * <informalfigure> (#7)
  * Fix content model for step to allow para, substeps,
  * para (#12)
  * Allow phrase inside productnumber (#13)
  * Both
  * Update Novdoc/GeekoDoc to disallow screen in entry (#2)
  * Spec file changes:
  * Generate Novdoc RNC/RNG files to add missing files
* Fri Sep 16 2016 sknorr@suse.com
- Added missing build dependency on trang
* Fri Aug 19 2016 fvogt@suse.com
- Initial package
